Global aspect registry for managing aspect-pointcut bindings.
The registry allows aspects to be registered with pointcut patterns, and then automatically applied to matching functions at runtime.
Structs
- Aspect
Registry - Global aspect registry for managing aspect-pointcut bindings.
- Registered
Aspect - A registered aspect with its associated pointcut and metadata.
Statics
- GLOBAL_
REGISTRY - Global aspect registry instance.
Functions
- global_
registry - Get a reference to the global aspect registry.